/*
  Pixie SPEED_TEST Example
  -----------------------
  
  Prints rapily to the Pixie chain for 1 second,
  then shows how many frames per second were
  achieved. This is dependent on how many
  Pixies are in the chain (more is slower)
  and which firmware the Pixies themselves
  are running.
  
  1.0.0  = pix.begin(LEGACY_SPEED) // ~ 39kHz bitrate
  1.1.0+ = pix.begin(FULL_SPEED)   // ~ 67kHz bitrate (Firmware 1.1.0+)
*/

#include "Pixie.h"
#define NUM_PIXIES  12                    // PCBs, not matrices
#define CLK_PIN     14                    // Any digital pin
#define DATA_PIN    12                    // Any digital pin
Pixie pix(NUM_PIXIES, CLK_PIN, DATA_PIN); // Set up display buffer

uint8_t animation[24][5] = { // 24 arrays of 5 uint8_t's (Icons)
  {0x01,0x00,0x00,0x00,0x00},
  {0x01,0x01,0x00,0x00,0x00},
  {0x01,0x01,0x01,0x00,0x00},
  {0x01,0x01,0x01,0x01,0x00},
  {0x01,0x01,0x01,0x01,0x01},
  {0x00,0x01,0x01,0x01,0x03},
  {0x00,0x00,0x01,0x01,0x07},
  {0x00,0x00,0x00,0x01,0x0F},
  {0x00,0x00,0x00,0x00,0x1F},
  {0x00,0x00,0x00,0x00,0x3E},
  {0x00,0x00,0x00,0x00,0x7C},
  {0x00,0x00,0x00,0x40,0x78},
  {0x00,0x00,0x40,0x40,0x70},
  {0x00,0x40,0x40,0x40,0x60},
  {0x40,0x40,0x40,0x40,0x40},
  {0x60,0x40,0x40,0x40,0x00},
  {0x70,0x40,0x40,0x00,0x00},
  {0x78,0x40,0x00,0x00,0x00},
  {0x7C,0x00,0x00,0x00,0x00},
  {0x3E,0x00,0x00,0x00,0x00},
  {0x1F,0x00,0x00,0x00,0x00},
  {0x0F,0x00,0x00,0x00,0x00},
  {0x07,0x00,0x00,0x00,0x00},
  {0x03,0x00,0x00,0x00,0x00}
};

void setup() {
  Serial.begin(115200);
  pix.begin(); // Init display drivers
}

void loop() {
  uint16_t FPS = 0;
  uint32_t t_start = millis();
  uint32_t t_end   = t_start + 1000;
  while(millis() < t_end){
    FPS++;
    pix.clear();
    pix.print(animation[FPS%24]);
    pix.show();    
  }
  pix.clear();
  pix.print(FPS);
  pix.print(" FPS!");
  pix.show();
  
  // Print FPS to Serial as well
  Serial.println(FPS);
  // Wait a moment
  delay(2000);
}